==> niftygate-0.6.0.crate: niftygate-0.6.0/src/openzeppelin/contracts/generated.rs <==
#![allow(clippy::all)]

pub mod access_control;
pub mod access_control_enumerable;
pub mod address;
pub mod arrays;
pub mod beacon_proxy;
pub mod bit_maps;
pub mod clones;
pub mod conditional_escrow;
pub mod context;
pub mod counters;
pub mod create_2;
pub mod ecdsa;
pub mod eip712;
pub mod enumerable_map;
pub mod enumerable_set;
pub mod erc1155;
pub mod erc1155_burnable;
pub mod erc1155_holder;
pub mod erc1155_pausable;
pub mod erc1155_preset_minter_pauser;
pub mod erc1155_receiver;
pub mod erc1155_supply;
pub mod erc165;
pub mod erc165_checker;
pub mod erc165_storage;
pub mod erc1820_implementer;
pub mod erc1967_proxy;
pub mod erc1967_upgrade;
pub mod erc20;
pub mod erc20_burnable;
pub mod erc20_capped;
pub mod erc20_flash_mint;
pub mod erc20_pausable;
pub mod erc20_permit;
pub mod erc20_preset_fixed_supply;
pub mod erc20_preset_minter_pauser;
pub mod erc20_snapshot;
pub mod erc20_votes;
pub mod erc20_votes_comp;
pub mod erc20_wrapper;
pub mod erc2771_context;
pub mod erc721;
pub mod erc721_burnable;
pub mod erc721_enumerable;
pub mod erc721_holder;
pub mod erc721_pausable;
pub mod erc721_preset_minter_pauser_auto_id;
pub mod erc721uri_storage;
pub mod erc777;
pub mod erc777_preset_fixed_supply;
pub mod escrow;
pub mod i_access_control;
pub mod i_access_control_enumerable;
pub mod i_beacon;
pub mod ierc1155;
pub mod ierc1155_metadata_uri;
pub mod ierc1155_receiver;
pub mod ierc1271;
pub mod ierc165;
pub mod ierc1820_implementer;
pub mod ierc1820_registry;
pub mod ierc20;
pub mod ierc20_metadata;
pub mod ierc20_permit;
pub mod ierc3156_flash_borrower;
pub mod ierc3156_flash_lender;
pub mod ierc721;
pub mod ierc721_enumerable;
pub mod ierc721_metadata;
pub mod ierc721_receiver;
pub mod ierc777;
pub mod ierc777_recipient;
pub mod ierc777_sender;
pub mod initializable;
pub mod math;
pub mod merkle_proof;
pub mod minimal_forwarder;
pub mod multicall;
pub mod ownable;
pub mod pausable;
pub mod payment_splitter;
pub mod proxy;
pub mod proxy_admin;
pub mod pull_payment;
pub mod reentrancy_guard;
pub mod refund_escrow;
pub mod safe_cast;
pub mod safe_erc20;
pub mod safe_math;
pub mod signature_checker;
pub mod signed_safe_math;
pub mod storage_slot;
pub mod strings;
pub mod timelock_controller;
pub mod token_timelock;
pub mod transparent_upgradeable_proxy;
pub mod upgradeable_beacon;
pub mod uups_upgradeable;

pub use access_control::*;
pub use access_control_enumerable::*;
pub use address::*;
pub use arrays::*;
pub use beacon_proxy::*;
pub use bit_maps::*;
pub use clones::*;
pub use conditional_escrow::*;
pub use context::*;
pub use counters::*;
pub use create_2::*;
pub use ecdsa::*;
pub use eip712::*;
pub use enumerable_map::*;
pub use enumerable_set::*;
pub use erc1155::*;
pub use erc1155_burnable::*;
pub use erc1155_holder::*;
pub use erc1155_pausable::*;
pub use erc1155_preset_minter_pauser::*;
pub use erc1155_receiver::*;
pub use erc1155_supply::*;
pub use erc165::*;
pub use erc165_checker::*;
pub use erc165_storage::*;
pub use erc1820_implementer::*;
pub use erc1967_proxy::*;
pub use erc1967_upgrade::*;
pub use erc20::*;
pub use erc20_burnable::*;
pub use erc20_capped::*;
pub use erc20_flash_mint::*;
pub use erc20_pausable::*;
pub use erc20_permit::*;
pub use erc20_preset_fixed_supply::*;
pub use erc20_preset_minter_pauser::*;
pub use erc20_snapshot::*;
pub use erc20_votes::*;
pub use erc20_votes_comp::*;
pub use erc20_wrapper::*;
pub use erc2771_context::*;
pub use erc721::*;
pub use erc721_burnable::*;
pub use erc721_enumerable::*;
pub use erc721_holder::*;
pub use erc721_pausable::*;
pub use erc721_preset_minter_pauser_auto_id::*;
pub use erc721uri_storage::*;
pub use erc777::*;
pub use erc777_preset_fixed_supply::*;
pub use escrow::*;
pub use i_access_control::*;
pub use i_access_control_enumerable::*;
pub use i_beacon::*;
pub use ierc1155::*;
pub use ierc1155_metadata_uri::*;
pub use ierc1155_receiver::*;
pub use ierc1271::*;
pub use ierc165::*;
pub use ierc1820_implementer::*;
pub use ierc1820_registry::*;
pub use ierc20::*;
pub use ierc20_metadata::*;
pub use ierc20_permit::*;
pub use ierc3156_flash_borrower::*;
pub use ierc3156_flash_lender::*;
pub use ierc721::*;
pub use ierc721_enumerable::*;
pub use ierc721_metadata::*;
pub use ierc721_receiver::*;
pub use ierc777::*;
pub use ierc777_recipient::*;
pub use ierc777_sender::*;
pub use initializable::*;
pub use math::*;
pub use merkle_proof::*;
pub use minimal_forwarder::*;
pub use multicall::*;
pub use ownable::*;
pub use pausable::*;
pub use payment_splitter::*;
pub use proxy::*;
pub use proxy_admin::*;
pub use pull_payment::*;
pub use reentrancy_guard::*;
pub use refund_escrow::*;
pub use safe_cast::*;
pub use safe_erc20::*;
pub use safe_math::*;
pub use signature_checker::*;
pub use signed_safe_math::*;
pub use storage_slot::*;
pub use strings::*;
pub use timelock_controller::*;
pub use token_timelock::*;
pub use transparent_upgradeable_proxy::*;
pub use upgradeable_beacon::*;
pub use uups_upgradeable::*;

==> niftygate-0.6.1.crate: niftygate-0.6.1/src/openzeppelin/contracts/generated.rs <==
#![allow(clippy::all)]

pub mod access_control;
pub mod access_control_enumerable;
pub mod address;
pub mod arrays;
pub mod beacon_proxy;
pub mod bit_maps;
pub mod clones;
pub mod conditional_escrow;
pub mod context;
pub mod counters;
pub mod create_2;
pub mod ecdsa;
pub mod eip712;
pub mod enumerable_map;
pub mod enumerable_set;
pub mod erc1155;
pub mod erc1155_burnable;
pub mod erc1155_holder;
pub mod erc1155_pausable;
pub mod erc1155_preset_minter_pauser;
pub mod erc1155_receiver;
pub mod erc1155_supply;
pub mod erc165;
pub mod erc165_checker;
pub mod erc165_storage;
pub mod erc1820_implementer;
pub mod erc1967_proxy;
pub mod erc1967_upgrade;
pub mod erc20;
pub mod erc20_burnable;
pub mod erc20_capped;
pub mod erc20_flash_mint;
pub mod erc20_pausable;
pub mod erc20_permit;
pub mod erc20_preset_fixed_supply;
pub mod erc20_preset_minter_pauser;
pub mod erc20_snapshot;
pub mod erc20_votes;
pub mod erc20_votes_comp;
pub mod erc20_wrapper;
pub mod erc2771_context;
pub mod erc721;
pub mod erc721_burnable;
pub mod erc721_enumerable;
pub mod erc721_holder;
pub mod erc721_pausable;
pub mod erc721_preset_minter_pauser_auto_id;
pub mod erc721uri_storage;
pub mod erc777;
pub mod erc777_preset_fixed_supply;
pub mod escrow;
pub mod governor;
pub mod governor_compatibility_bravo;
pub mod governor_counting_simple;
pub mod governor_proposal_threshold;
pub mod governor_timelock_compound;
pub mod governor_timelock_control;
pub mod governor_votes;
pub mod governor_votes_comp;
pub mod governor_votes_quorum_fraction;
pub mod i_access_control;
pub mod i_access_control_enumerable;
pub mod i_beacon;
pub mod i_compound_timelock;
pub mod i_governor;
pub mod i_governor_compatibility_bravo;
pub mod i_governor_timelock;
pub mod ierc1155;
pub mod ierc1155_metadata_uri;
pub mod ierc1155_receiver;
pub mod ierc1271;
pub mod ierc1363;
pub mod ierc1363_receiver;
pub mod ierc1363_spender;
pub mod ierc165;
pub mod ierc1820_implementer;
pub mod ierc1820_registry;
pub mod ierc20;
pub mod ierc20_metadata;
pub mod ierc20_permit;
pub mod ierc2612;
pub mod ierc2981;
pub mod ierc3156_flash_borrower;
pub mod ierc3156_flash_lender;
pub mod ierc721;
pub mod ierc721_enumerable;
pub mod ierc721_metadata;
pub mod ierc721_receiver;
pub mod ierc777;
pub mod ierc777_recipient;
pub mod ierc777_sender;
pub mod initializable;
pub mod math;
pub mod merkle_proof;
pub mod minimal_forwarder;
pub mod multicall;
pub mod ownable;
pub mod pausable;
pub mod payment_splitter;
pub mod proxy;
pub mod proxy_admin;
pub mod pull_payment;
pub mod reentrancy_guard;
pub mod refund_escrow;
pub mod safe_cast;
pub mod safe_erc20;
pub mod safe_math;
pub mod signature_checker;
pub mod signed_safe_math;
pub mod storage_slot;
pub mod strings;
pub mod timelock_controller;
pub mod timers;
pub mod token_timelock;
pub mod transparent_upgradeable_proxy;
pub mod upgradeable_beacon;
pub mod uups_upgradeable;

pub use access_control::*;
pub use access_control_enumerable::*;
pub use address::*;
pub use arrays::*;
pub use beacon_proxy::*;
pub use bit_maps::*;
pub use clones::*;
pub use conditional_escrow::*;
pub use context::*;
pub use counters::*;
pub use create_2::*;
pub use ecdsa::*;
pub use eip712::*;
pub use enumerable_map::*;
pub use enumerable_set::*;
pub use erc1155::*;
pub use erc1155_burnable::*;
pub use erc1155_holder::*;
pub use erc1155_pausable::*;
pub use erc1155_preset_minter_pauser::*;
pub use erc1155_receiver::*;
pub use erc1155_supply::*;
pub use erc165::*;
pub use erc165_checker::*;
pub use erc165_storage::*;
pub use erc1820_implementer::*;
pub use erc1967_proxy::*;
pub use erc1967_upgrade::*;
pub use erc20::*;
pub use erc20_burnable::*;
pub use erc20_capped::*;
pub use erc20_flash_mint::*;
pub use erc20_pausable::*;
pub use erc20_permit::*;
pub use erc20_preset_fixed_supply::*;
pub use erc20_preset_minter_pauser::*;
pub use erc20_snapshot::*;
pub use erc20_votes::*;
pub use erc20_votes_comp::*;
pub use erc20_wrapper::*;
pub use erc2771_context::*;
pub use erc721::*;
pub use erc721_burnable::*;
pub use erc721_enumerable::*;
pub use erc721_holder::*;
pub use erc721_pausable::*;
pub use erc721_preset_minter_pauser_auto_id::*;
pub use erc721uri_storage::*;
pub use erc777::*;
pub use erc777_preset_fixed_supply::*;
pub use escrow::*;
pub use governor::*;
pub use governor_compatibility_bravo::*;
pub use governor_counting_simple::*;
pub use governor_proposal_threshold::*;
pub use governor_timelock_compound::*;
pub use governor_timelock_control::*;
pub use governor_votes::*;
pub use governor_votes_comp::*;
pub use governor_votes_quorum_fraction::*;
pub use i_access_control::*;
pub use i_access_control_enumerable::*;
pub use i_beacon::*;
pub use i_compound_timelock::*;
pub use i_governor::*;
pub use i_governor_compatibility_bravo::*;
pub use i_governor_timelock::*;
pub use ierc1155::*;
pub use ierc1155_metadata_uri::*;
pub use ierc1155_receiver::*;
pub use ierc1271::*;
pub use ierc1363::*;
pub use ierc1363_receiver::*;
pub use ierc1363_spender::*;
pub use ierc165::*;
pub use ierc1820_implementer::*;
pub use ierc1820_registry::*;
pub use ierc20::*;
pub use ierc20_metadata::*;
pub use ierc20_permit::*;
pub use ierc2612::*;
pub use ierc2981::*;
pub use ierc3156_flash_borrower::*;
pub use ierc3156_flash_lender::*;
pub use ierc721::*;
pub use ierc721_enumerable::*;
pub use ierc721_metadata::*;
pub use ierc721_receiver::*;
pub use ierc777::*;
pub use ierc777_recipient::*;
pub use ierc777_sender::*;
pub use initializable::*;
pub use math::*;
pub use merkle_proof::*;
pub use minimal_forwarder::*;
pub use multicall::*;
pub use ownable::*;
pub use pausable::*;
pub use payment_splitter::*;
pub use proxy::*;
pub use proxy_admin::*;
pub use pull_payment::*;
pub use reentrancy_guard::*;
pub use refund_escrow::*;
pub use safe_cast::*;
pub use safe_erc20::*;
pub use safe_math::*;
pub use signature_checker::*;
pub use signed_safe_math::*;
pub use storage_slot::*;
pub use strings::*;
pub use timelock_controller::*;
pub use timers::*;
pub use token_timelock::*;
pub use transparent_upgradeable_proxy::*;
pub use upgradeable_beacon::*;
pub use uups_upgradeable::*;
